@@ -14,10 +14,12 @@ from .datasets.build import build_dataset
 from .transforms.build import build_transform
 from .dataloader.build import build_dataloader
 
+from .datasets.mp_dataset import MPDataset
 
-def build_data(cfg, is_train=True):
+
+def build_data(cfg, is_train=True, **kwargs):
     transform, target_transform = build_transform(cfg, is_train=is_train)
-    dataset = build_dataset(cfg, transform=transform, target_transform=target_transform, is_train=is_train)
+    dataset = build_dataset(cfg, transform=transform, target_transform=target_transform, is_train=is_train, **kwargs)
 
     return build_dataloader(cfg, dataset, is_train=is_train)
 
@@ -32,11 +34,16 @@ def shuffle_dataset(loader, cur_epoch, is_shuffle=False):
     """
     if not is_shuffle:
         return
-    sampler = loader.sampler
-    assert isinstance(
-        sampler, (RandomSampler, DistributedSampler)
-    ), "Sampler type '{}' not supported".format(type(sampler))
-    # RandomSampler handles shuffling automatically
-    if isinstance(sampler, DistributedSampler):
-        # DistributedSampler shuffles data based on epoch
-        sampler.set_epoch(cur_epoch)
+
+    dataset = loader.dataset
+    if isinstance(dataset, MPDataset):
+        dataset.set_epoch(cur_epoch)
+    else:
+        sampler = loader.sampler
+        assert isinstance(
+            sampler, (RandomSampler, DistributedSampler)
+        ), "Sampler type '{}' not supported".format(type(sampler))
+        # RandomSampler handles shuffling automatically
+        if isinstance(sampler, DistributedSampler):
+            # DistributedSampler shuffles data based on epoch
+            sampler.set_epoch(cur_epoch)
