@@ -38,8 +38,10 @@ def topk_accuracy(output, target, top_k=(1,)):
     correct = pred.eq(target.view(1, -1).expand_as(pred))
 
     res = []
+    res_correct = []
     for k in top_k:
         # correct_k = correct[:k].view(-1).float().sum(0)
         correct_k = correct[:k].reshape(-1).float().sum(0)
+        res_correct.append(int(correct_k))
         res.append(correct_k.mul_(100.0 / batch_size))
-    return res
+    return res, res_correct
